@@ -156,6 +156,10 @@ Keymap for characters following C-c.")
 (define-key global-map (vector help-char) 'help-command)
 (define-key global-map 'help 'help-command)
 (define-key global-map 'f1 'help-command)
+;; This is a failsafe mechanism, esp. on TTY's, in case the terminal is
+;; somewhat broken and f1 keys can't work, and backspace is redefined to
+;; do backspace.
+(define-key global-map '(meta ??) 'help-command)
 
 ;; FSFmacs indent.el
 
@@ -333,9 +337,11 @@ Keymap for characters following C-c.")
 (define-key global-map "\C-xr+" 'increment-register)
 (define-key global-map "\C-xrc" 'clear-rectangle)
 (define-key global-map "\C-xrk" 'kill-rectangle)
+(define-key global-map "\C-xrd" 'delete-rectangle)
 (define-key global-map "\C-xry" 'yank-rectangle)
 (define-key global-map "\C-xro" 'open-rectangle)
 (define-key global-map "\C-xrt" 'string-rectangle)
+(define-key global-map "\C-xrp" 'replace-rectangle)
 (define-key global-map "\C-xrw" 'window-configuration-to-register)
 ;(define-key global-map "\C-xrf" 'frame-configuration-to-register)
 
